==> subversion-2.7.1.1-sources.jar: jenkins/scm/impl/subversion/Messages.java <==
// CHECKSTYLE:OFF

package jenkins.scm.impl.subversion;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code SubversionStep.subversion}: {@code Subversion}.
     * 
     * @return
     *     {@code Subversion}
     */
    public static String SubversionStep_subversion() {
        return holder.format("SubversionStep.subversion");
    }

    /**
     * Key {@code SubversionStep.subversion}: {@code Subversion}.
     * 
     * @return
     *     {@code Subversion}
     */
    public static Localizable _SubversionStep_subversion() {
        return new Localizable(holder, "SubversionStep.subversion");
    }

    /**
     * Key {@code SubversionSCMSource.DisplayName}: {@code Subversion}.
     * 
     * @return
     *     {@code Subversion}
     */
    public static String SubversionSCMSource_DisplayName() {
        return holder.format("SubversionSCMSource.DisplayName");
    }

    /**
     * Key {@code SubversionSCMSource.DisplayName}: {@code Subversion}.
     * 
     * @return
     *     {@code Subversion}
     */
    public static Localizable _SubversionSCMSource_DisplayName() {
        return new Localizable(holder, "SubversionSCMSource.DisplayName");
    }

}

==> subversion-2.15.1-sources.jar: jenkins/scm/impl/subversion/Messages.java <==
// CHECKSTYLE:OFF

package jenkins.scm.impl.subversion;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;
import org.kohsuke.accmod.Restricted;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
@Restricted(org.kohsuke.accmod.restrictions.NoExternalUse.class)
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code SubversionStep.subversion}: {@code Subversion}.
     * 
     * @return
     *     {@code Subversion}
     */
    public static String SubversionStep_subversion() {
        return holder.format("SubversionStep.subversion");
    }

    /**
     * Key {@code SubversionStep.subversion}: {@code Subversion}.
     * 
     * @return
     *     {@code Subversion}
     */
    public static Localizable _SubversionStep_subversion() {
        return new Localizable(holder, "SubversionStep.subversion");
    }

    /**
     * Key {@code SubversionSCMSource.DisplayName}: {@code Subversion}.
     * 
     * @return
     *     {@code Subversion}
     */
    public static String SubversionSCMSource_DisplayName() {
        return holder.format("SubversionSCMSource.DisplayName");
    }

    /**
     * Key {@code SubversionSCMSource.DisplayName}: {@code Subversion}.
     * 
     * @return
     *     {@code Subversion}
     */
    public static Localizable _SubversionSCMSource_DisplayName() {
        return new Localizable(holder, "SubversionSCMSource.DisplayName");
    }

}
